summaryrefslogtreecommitdiffstats
path: root/kbackgammon/kbgboard.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kbackgammon/kbgboard.cpp')
-rw-r--r--kbackgammon/kbgboard.cpp38
1 files changed, 19 insertions, 19 deletions
diff --git a/kbackgammon/kbgboard.cpp b/kbackgammon/kbgboard.cpp
index a065ec40..ba2d1829 100644
--- a/kbackgammon/kbgboard.cpp
+++ b/kbackgammon/kbgboard.cpp
@@ -248,8 +248,8 @@ void KBgBoardSetup::getSetupPages(KDialogBase *nb)
/*
* Empty constructor calls the board constructor
*/
-KBgBoardSetup::KBgBoardSetup(TQWidget *tqparent, const char *name, TQPopupMenu *menu)
- : KBgBoard(tqparent, name, menu)
+KBgBoardSetup::KBgBoardSetup(TQWidget *parent, const char *name, TQPopupMenu *menu)
+ : KBgBoard(parent, name, menu)
{
// empty
}
@@ -1610,8 +1610,8 @@ KBgBoardField::~KBgBoardField()
* This is the constructor of the bars. It calls the base class' constructor
* and defines the TQWhatsThis string.
*/
-KBgBoardBar::KBgBoardBar(TQWidget * tqparent, int numID)
- : KBgBoardCell(tqparent, numID)
+KBgBoardBar::KBgBoardBar(TQWidget * parent, int numID)
+ : KBgBoardCell(parent, numID)
{
TQWhatsThis::add(this, i18n("This is the bar of the backgammon board.\n\n"
"Checkers that have been kicked from the board are put "
@@ -1627,8 +1627,8 @@ KBgBoardBar::KBgBoardBar(TQWidget * tqparent, int numID)
* This is the constructor of regular fields. It calls the base class' constructor
* and defines the TQWhatsThis string.
*/
-KBgBoardField::KBgBoardField(TQWidget * tqparent, int numID)
- : KBgBoardCell(tqparent, numID)
+KBgBoardField::KBgBoardField(TQWidget * parent, int numID)
+ : KBgBoardCell(parent, numID)
{
TQWhatsThis::add(this, i18n("This is a regular field of the backgammon board.\n\n"
"Checkers can be placed on this field and if the current state "
@@ -1641,8 +1641,8 @@ KBgBoardField::KBgBoardField(TQWidget * tqparent, int numID)
* This is the constructor of the homes. It calls the base class' constructor
* and defines the TQWhatsThis string.
*/
-KBgBoardHome::KBgBoardHome(TQWidget * tqparent, int numID)
- : KBgBoardCell(tqparent, numID)
+KBgBoardHome::KBgBoardHome(TQWidget * parent, int numID)
+ : KBgBoardCell(parent, numID)
{
TQWhatsThis::add(this, i18n("This part of the backgammon board is the home.\n\n"
"Depending on the direction of the game, one of the homes "
@@ -1734,10 +1734,10 @@ int KBgBoard::getTurn() const
* This is the constructor of the basic cells. It initializes the cell
* to a sane state and connects a signal to the board.
*/
-KBgBoardCell::KBgBoardCell(TQWidget * tqparent, int numID)
- : TQLabel(tqparent)
+KBgBoardCell::KBgBoardCell(TQWidget * parent, int numID)
+ : TQLabel(parent)
{
- board = (KBgBoard *)tqparent;
+ board = (KBgBoard *)parent;
direction = +1;
color = -1;
@@ -1749,7 +1749,7 @@ KBgBoardCell::KBgBoardCell(TQWidget * tqparent, int numID)
mouseButton = Qt::NoButton;
dragInProgress = false;
- connect(tqparent, TQT_SIGNAL(finishedUpdate()), this, TQT_SLOT(refresh()));
+ connect(parent, TQT_SIGNAL(finishedUpdate()), this, TQT_SLOT(refresh()));
}
/*
@@ -1854,7 +1854,7 @@ void KBgBoard::updateField(int f, int v)
}
/*
* This function displays the context menu our tqparent may have given us
*/
void KBgBoard::showContextMenu()
{
@@ -2162,10 +2162,10 @@ void KBgBoardCell::mouseMoveEvent(TQMouseEvent *)
board->drawSimpleChecker(&tmp, 0, 0, pcs, getCheckerDiameter());
tmp.end();
pix.setMask(pix.createHeuristicMask());
- TQBitmap tqmask = *(pix.tqmask());
+ TQBitmap mask = *(pix.mask());
TQBitmap newCursor;
newCursor = pix;
- board->replaceCursor(TQCursor(newCursor, tqmask));
+ board->replaceCursor(TQCursor(newCursor, mask));
if (board->getEditMode())
board->storeTurn(pcs);
getPiece();
@@ -2653,7 +2653,7 @@ void KBgBoard::redoMove()
}
/*
* This function performs and undo for the last move and updates the tqparent
* of the board by calling sendMove() after the undo.
*/
void KBgBoard::undoMove()
@@ -2823,8 +2823,8 @@ void KBgBoard::getRollDice(const int w)
* You have to change the status by passing a KBgtqStatus
* object to setState(...) before you can play!
*/
-KBgBoard::KBgBoard(TQWidget *tqparent, const char *name, TQPopupMenu *menu)
- : TQWidget(tqparent, name)
+KBgBoard::KBgBoard(TQWidget *parent, const char *name, TQPopupMenu *menu)
+ : TQWidget(parent, name)
{
/*
* The following lines set up internal bookkeeping data.
@@ -2838,7 +2838,7 @@ KBgBoard::KBgBoard(TQWidget *tqparent, const char *name, TQPopupMenu *menu)
checkerDiam = MINIMUM_CHECKER_SIZE;
/*
* We may be initialized with a popup menu by our tqparent.
*/
contextMenu = menu;
@@ -1854,7 +1854,7 @@ void KBgBoard::updateField(int f, int v)
}
/*
- * This function displays the context menu our tqparent may have given us
+ * This function displays the context menu our parent may have given us
*/
void KBgBoard::showContextMenu()
@@ -2653,7 +2653,7 @@ void KBgBoard::redoMove()
}
/*
- * This function performs and undo for the last move and updates the tqparent
+ * This function performs and undo for the last move and updates the parent
* of the board by calling sendMove() after the undo.
*/
@@ -2838,7 +2838,7 @@ KBgBoard::KBgBoard(TQWidget *tqparent, const char *name, TQPopupMenu *menu)
checkerDiam = MINIMUM_CHECKER_SIZE;
/*
- * We may be initialized with a popup menu by our tqparent.
+ * We may be initialized with a popup menu by our parent.
*/
contextMenu = menu;